summaryrefslogtreecommitdiff
path: root/web/app.js
diff options
context:
space:
mode:
Diffstat (limited to 'web/app.js')
-rw-r--r--web/app.js10
1 files changed, 5 insertions, 5 deletions
diff --git a/web/app.js b/web/app.js
index 73f5a5c..dca4472 100644
--- a/web/app.js
+++ b/web/app.js
@@ -107,8 +107,7 @@ export function renderDeploymentBadge(status, doc = (typeof document !== 'undefi
span.className = 'deployment-badge deployment-badge--deployed';
span.textContent = '✓ Deployed';
} else {
- span.className = 'deployment-badge deployment-badge--pending';
- span.textContent = '⚠ Not deployed';
+ return null;
}
if (status.deployed_commit) {
span.title = `Deployed commit: ${status.deployed_commit.slice(0, 8)}`;
@@ -179,8 +178,9 @@ function createTaskCard(task) {
if (csBadge) card.appendChild(csBadge);
}
- // Deployment status badge for READY tasks
- if (task.state === 'READY' && task.deployment_status != null) {
+ // Deployment status badge for READY tasks — only when there are tracked commits to check.
+ if (task.state === 'READY' && task.deployment_status != null &&
+ task.deployment_status.fix_commits && task.deployment_status.fix_commits.length > 0) {
const depBadge = renderDeploymentBadge(task.deployment_status);
if (depBadge) card.appendChild(depBadge);
}
@@ -2660,7 +2660,7 @@ async function enableNotifications(btn) {
if (!res.ok) throw new Error(`Subscribe failed: HTTP ${res.status}`);
if (btn) {
- btn.textContent = '🔔 On';
+ btn.textContent = '🔔';
btn.disabled = true;
}
} catch (err) {